| Title: | Support Files for Building Next Generation Clustered Heat Maps (NG-CHMs) |
|---|---|
| Description: | Support files required by the 'NGCHM' package to export Next-Generation Clustered Heat Maps (NG-CHMs) to .ngchm, HTML, and PDF files. These support files are updated mostly independently from the 'NGCHM' package, and are therefore provided separately. |
| Authors: | Bradley M Broom [aut] (ORCID: <https://orcid.org/0000-0002-0915-3164>), Mary A Rohrdanz [ctb, cre], Chris Wakefield [ctb], James Melott [ctb], Mark Stucky [aut], Michael Ryan [aut], Futa Ikeda [ctb], MD Anderson Cancer Center [cph] |
| Maintainer: | Mary A Rohrdanz <[email protected]> |
| License: | GPL-3 |
| Version: | 2.27.2 |
| Built: | 2026-06-07 06:14:01 UTC |
| Source: | https://github.com/MD-Anderson-Bioinformatics/NGCHMSupportFiles |
Support Files for 'NGCHM' package
Files provided by this package:
ShaidyMapGen.jar - Compiled Java code. Used by NGCHM::chmExportToFile(),NGCHM::chmExportToHTML(), NGCHM::chmExportToPDF() to produce .ngchm, .html, and .pdf files, respectively.
ngchmWidget-min.js - JavaScript library used to display NG-CHMs in a web browser. Used by NGCHM::chmExportToHTML().
These Support Files are made available to the 'NGCHM' package via environment variables, SHAIDYMAPGEN
and NGCHMWIDGETPATH, which are
set when this package loads. These files are required to export a Next-Generation Clustered Heat Map (NG-CHM)
to a .ngchm, .html, or .pdf file.
Installation
This package can be installed from MD Anderson Bioinformatics R-universe repository:
install.packages("NGCHMSupportFiles",repos = c("https://md-anderson-bioinformatics.r-universe.dev",
"https://cran.r-project.org"))
Maintainer: Mary A Rohrdanz [email protected] [contributor]
Authors:
Bradley M Broom [email protected] (ORCID)
Mark Stucky
Michael Ryan
Other contributors:
Chris Wakefield [email protected] [contributor]
James Melott [email protected] [contributor]
Futa Ikeda [contributor]
MD Anderson Cancer Center [copyright holder]
Useful links:
https://github.com/MD-Anderson-Bioinformatics/NGCHMSupportFiles
https://md-anderson-bioinformatics.r-universe.dev/NGCHMSupportFiles
Display message to user that environment variables were set for:
SHAIDYMAPGEN - Path to the included file ShaidyMapGen.jar
NGCHMWIDGETPATH - Path to the included file ngchmWidget-min.js
.onAttach(libname, pkgname).onAttach(libname, pkgname)
libname |
name of the library |
pkgname |
name of the package |
Define environment variables:
SHAIDYMAPGEN - Path to the included file ShaidyMapGen.jar
NGCHMWIDGETPATH - Path to the included file ngchmWidget-min.js
.onLoad(libname, pkgname).onLoad(libname, pkgname)
libname |
name of the library |
pkgname |
name of the package |